SchemaSpy - Table gnss_data.public.ppp_soln_excl

Tables Relationships Utility Tables Constraints Anomalies Columns Donate

Table gnss_data.public.ppp_soln_excl | Generated by SchemaSpy

Related columns Constraints Comments Legend |
Legend: |
Primary key columns
Columns with indexes
Implied relationships
Excluded column relationships
< n > number of related tables
Column | Type | Size | Nulls | Auto | Default | Children | Parents | Comments
--- | --- | --- | --- | --- | --- | --- | --- | ---
NetworkCode | varchar | 3 |  |  |  |  |
stations.NetworkCode | ppp_soln_excl_NetworkCode_fkey R
StationCode | varchar | 4 |  |  |  |  |
stations.StationCode | ppp_soln_excl_NetworkCode_fkey R
Year | numeric | 131089 |  |  |  |  |  |
DOY | numeric | 131089 |  |  |  |  |  |
Table contained 1 rows at Fri Jul 28 14:55 EDT 2017

Close relationships within one two degrees of separation: